@@ -1,4 +1,4 @@
-var parse = require('acorn').parse;
+var parse = require('acorn-node').parse;
 
 module.exports = function (src) {
     // If src is a Buffer, esprima will just stringify it, so we beat them to
@@ -9,10 +9,7 @@ module.exports = function (src) {
         src = String(src);
     }
 
-    var ast = parse(src, {
-      range: true,
-      ecmaVersion: 2019
-    });
+    var ast = parse(src, { range: true });
 
     ast.body = ast.body.filter(function(node) {
         return node.type !== 'EmptyStatement';
